{
  alsa-lib,
  gtk3,
  fetchFromGitHub,
  rustPlatform,
  openssl,
  pkg-config,
  jack2,
  python3,
  cmake,
  libopus,
  steam-run,
  writeShellApplication,
}:
let
  entangled = rustPlatform.buildRustPackage rec {
    pname = "noita-entangled-worlds-proxy";
    version = "v1.5.1";

    src = fetchFromGitHub {
      owner = "IntQuant";
      repo = "noita_entangled_worlds";
      rev = version;
      hash = "sha256-v5aulgWkPhgkPHfHb1j/39JauKfFhFCHRfBgm2UJHYc=";
    };

    sourceRoot = "${src.name}/noita-proxy";

    useFetchCargoVendor = true;
    cargoHash = "sha256-1YkLTp3QUaC1oU1SwmuOJMTklptfZu2gIonDyLfLhCk=";
    buildInputs = [
      gtk3
      openssl
      jack2
      alsa-lib
      libopus
    ];
    nativeBuildInputs = [
      pkg-config
      python3
      cmake
    ];
    preInstall = ''
      mkdir -p $out/share/lib64/noita-proxy
      cp -r ${src}/redist/libsteam_api.so $out/share/lib64/noita-proxy
    '';
    checkFlags = [
      # reason for disabling test
      "--skip=bookkeeping::releases::test::release_assets"
    ];
  };
in
writeShellApplication {
  name = "noita-proxy-${entangled.version}";
  runtimeInputs = [
    entangled
    steam-run
  ];
  text = ''
    export LD_PRELOAD=${entangled}/share/lib64/noita-proxy/libsteam_api.so
    exec steam-run "${entangled}/bin/noita-proxy" "$@"
  '';
}
